//---------------------------------------------------------------------------
// File: TMainForm.h
//
//  TDx_Input_Library v1.4
//  Example5- Force Feedback Joysticks
//
// Date: 17th May, 2001
// Author: Darren John Dwyer
// Copyright: (c) 2001 Darren John Dwyer, All Rights Reserved.
//
// Description:
//
// This example shows how to control a Force Feedback Joystick,
// (or other Force Feedback Device)
//
// It helps significantly if you view and understand the previous DirectInput
// examples before you try to understand this demo.
//
//---------------------------------------------------------------------------
#ifndef TMainFormH
#define TMainFormH
//---------------------------------------------------------------------------
#include <vcl\Classes.hpp>
#include <vcl\Controls.hpp>
#include <vcl\StdCtrls.hpp>
#include <vcl\Forms.hpp>
#include "TDx_Input.h"
#include "TDx_Input_Library_Install.h"
#include <vcl\Buttons.hpp>
#include "TDx_InputDevice.h"
#include "TDIDevCaps.h"
#include "tdx_inputeffect.h"
#include "tdidataformat.h"
#include "tdijoystate2.h"
#include "tdipropdword.h"
#include "tdipropheader.h"
#include "tdiperiodic.h"
#include "tdienvelope.h"
#include "tdieffect.h"
//---------------------------------------------------------------------------

#if (__BORLANDC__ < 0x0530) // BCB Version 1
class TMainForm : public TForm
{
#else // BCB Version 3 or 4
class PACKAGE TMainForm : public TForm
{
#endif

__published:
//---------------------------------------------------------------------------
// Anything that is to be displayed within the Object Inspector
//---------------------------------------------------------------------------

    TDx_Input *Dx_Input1;
    TBitBtn *EnumerateButton;
    TListBox *DevicesListBox;
    TLabel *Label2;
    TLabel *Label1;
    TMemo *InfoMemo;
    TLabel *Label5;
    TMemo *StatusMemo;
    TBitBtn *ClearMessagesButton;
    TBitBtn *ExitButton;
    TBitBtn *CreateDefaultButton;
    TBitBtn *CreateSelectedButton;
    TDx_InputDevice *Dx_InputDevice1;
    TListBox *DeviceCapsListBox;
    TLabel *Label3;
    TBitBtn *RetrieveCapsButton;
    TDIDevCaps *DIDevCaps1;
    TBitBtn *DestroyActiveButton;
    TBitBtn *DestroyInterfaceButton;
    TDx_InputEffect *Dx_InputEffect1;
    TDIJoyState2 *DIJoyState21;
    TDIPropDWORD *DIPropDWORD1;
    TDIPropHeader *DIPropHeader1;
    TBitBtn *CreateEffectButton;
    TDIPeriodic *DIPeriodic1;
    TDIEnvelope *DIEnvelope1;
    TDIEffect *DIEffect1;
    TBitBtn *EnumEffectsButton;
    TBitBtn *PlayEffectButton;
    TBitBtn *StopEffectButton;
    TListBox *EffectsListBox;
    TLabel *Label4;
    void __fastcall FormCreate(TObject *Sender);
    void __fastcall FormDestroy(TObject *Sender);
    void __fastcall EnumerateButtonClick(TObject *Sender);
    void __fastcall ExitButtonClick(TObject *Sender);
    void __fastcall ClearMessagesButtonClick(TObject *Sender);
    
    void __fastcall Dx_Input1EnumDevices(TObject *Sender,
    TDIDeviceInstance *DeviceInstance, void *Context, bool &Finished);
    void __fastcall Dx_Input1Error(TObject *Sender, AnsiString Function,
    AnsiString Error, AnsiString ErrorMessage);
    void __fastcall CreateDefaultButtonClick(TObject *Sender);
    void __fastcall Dx_Input1Create(TObject *Sender);
    
    void __fastcall DevicesListBoxClick(TObject *Sender);
    void __fastcall CreateSelectedButtonClick(TObject *Sender);
    void __fastcall Dx_Input1Destroy(TObject *Sender);
    void __fastcall Dx_InputDevice1Create(TObject *Sender);
    void __fastcall Dx_InputDevice1Destroy(TObject *Sender);
    void __fastcall RetrieveCapsButtonClick(TObject *Sender);
    void __fastcall DestroyActiveButtonClick(TObject *Sender);
    void __fastcall DestroyInterfaceButtonClick(TObject *Sender);
    
    void __fastcall Dx_InputDevice1EnumEffects(TObject *Sender, TDIEffectInfo *EffectInfo, void *Context,
    bool &Finished);
    void __fastcall CreateEffectButtonClick(TObject *Sender);
    void __fastcall EnumEffectsButtonClick(TObject *Sender);
    void __fastcall PlayEffectButtonClick(TObject *Sender);
    void __fastcall StopEffectButtonClick(TObject *Sender);
    void __fastcall EffectsListBoxClick(TObject *Sender);
public:
//---------------------------------------------------------------------------
// Anything available to other classes and/or code
//---------------------------------------------------------------------------

    __fastcall TMainForm(TComponent* Owner);
    virtual __fastcall ~TMainForm();

protected:
//---------------------------------------------------------------------------
// Anything available only to classes descended from this class
//---------------------------------------------------------------------------

private:
//---------------------------------------------------------------------------
// Private data not accessible except from within this class
//---------------------------------------------------------------------------

    #define MAX_DEVICES 5

    dword       DevTypes[MAX_DEVICES];
    GUID        FFDriverGuids[MAX_DEVICES];
    GUID        InstanceGuids[MAX_DEVICES];
    AnsiString  InstanceNames[MAX_DEVICES];
    GUID        ProductGuids[MAX_DEVICES];
    AnsiString  ProductNames[MAX_DEVICES];
    word        Usages[MAX_DEVICES];
    word        UsagePages[MAX_DEVICES];
    int         NumDevices;

    #define MAX_EFFECTS 25

    dword       EffectDynamicParams[MAX_EFFECTS];
    dword       EffectTypes[MAX_EFFECTS];
    GUID        EffectGuids[MAX_EFFECTS];
    AnsiString  EffectNames[MAX_EFFECTS];
    dword       EffectStaticParams[MAX_EFFECTS];
    int         NumEffects;

};
//---------------------------------------------------------------------------
#if (__BORLANDC__ < 0x0530) // BCB Version 1
extern TMainForm *MainForm;
#else // BCB Version 3 or 4
extern PACKAGE TMainForm *MainForm;
#endif
//---------------------------------------------------------------------------
#endif
